@@ -210,7 +210,7 @@ g_dbus_method_invocation_get_method_name (GDBusMethodInvocation *invocation)
  *
  * Gets the #GDBusConnection the method was invoked on.
  *
- * Returns: A #GDBusConnection. Do not free, it is owned by @invocation.
+ * Returns: (transfer none):A #GDBusConnection. Do not free, it is owned by @invocation.
  *
  * Since: 2.26
  */
@@ -234,7 +234,7 @@ g_dbus_method_invocation_get_connection (GDBusMethodInvocation *invocation)
  * linkend="gdbus-unix-fd-client"/> for an example of how to use this
  * low-level API to send and receive UNIX file descriptors.
  *
- * Returns: A #GDBusMessage. Do not free, it is owned by @invocation.
+ * Returns: (transfer none): #GDBusMessage. Do not free, it is owned by @invocation.
  *
  * Since: 2.26
  */
@@ -249,9 +249,10 @@ g_dbus_method_invocation_get_message (GDBusMethodInvocation *invocation)
  * g_dbus_method_invocation_get_parameters:
  * @invocation: A #GDBusMethodInvocation.
  *
- * Gets the parameters of the method invocation.
+ * Gets the parameters of the method invocation. If there are no input
+ * parameters then this will return a GVariant with 0 children rather than NULL.
  *
- * Returns: A #GVariant. Do not free, it is owned by @invocation.
+ * Returns: (transfer none): A #GVariant tuple. Do not unref this because it is owned by @invocation.
  *
  * Since: 2.26
  */
@@ -263,7 +264,7 @@ g_dbus_method_invocation_get_parameters (GDBusMethodInvocation *invocation)
 }
 
 /**
- * g_dbus_method_invocation_get_user_data:
+ * g_dbus_method_invocation_get_user_data: (skip)
  * @invocation: A #GDBusMethodInvocation.
  *
  * Gets the @user_data #gpointer passed to g_dbus_connection_register_object().
@@ -279,8 +280,8 @@ g_dbus_method_invocation_get_user_data (GDBusMethodInvocation *invocation)
   return invocation->user_data;
 }
 
-/**
- * g_dbus_method_invocation_new:
+/* < internal >
+ * _g_dbus_method_invocation_new:
  * @sender: The bus name that invoked the method or %NULL if @connection is not a bus connection.
  * @object_path: The object path the method was invoked on.
  * @interface_name: The name of the D-Bus interface the method was invoked on.
@@ -298,15 +299,15 @@ g_dbus_method_invocation_get_user_data (GDBusMethodInvocation *invocation)
  * Since: 2.26
  */
 GDBusMethodInvocation *
-g_dbus_method_invocation_new (const gchar           *sender,
-                              const gchar           *object_path,
-                              const gchar           *interface_name,
-                              const gchar           *method_name,
-                              const GDBusMethodInfo *method_info,
-                              GDBusConnection       *connection,
-                              GDBusMessage          *message,
-                              GVariant              *parameters,
-                              gpointer               user_data)
+_g_dbus_method_invocation_new (const gchar           *sender,
+                               const gchar           *object_path,
+                               const gchar           *interface_name,
+                               const gchar           *method_name,
+                               const GDBusMethodInfo *method_info,
+                               GDBusConnection       *connection,
+                               GDBusMessage          *message,
+                               GVariant              *parameters,
+                               gpointer               user_data)
 {
   GDBusMethodInvocation *invocation;
 
