@@ -16,20 +16,36 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#if !defined (__GLIB_GOBJECT_H_INSIDE__) && !defined (GOBJECT_COMPILATION)
+#error "Only <glib-object.h> can be included directly."
+#endif
 
 #ifndef __G_SOURCECLOSURE_H__
+#define __G_SOURCECLOSURE_H__
 
 #include <gobject/gclosure.h>
 
 G_BEGIN_DECLS
 
-void g_source_set_closure (GSource  *source,
-			   GClosure *closure);
+void g_source_set_closure        (GSource  *source,
+				  GClosure *closure);
+
+void g_source_set_dummy_callback (GSource  *source);
 
 GType g_io_channel_get_type   (void);
 GType g_io_condition_get_type (void);
 
+/**
+ * G_TYPE_IO_CHANNEL:
+ * 
+ * The #GType for #GIOChannel.
+ */
 #define G_TYPE_IO_CHANNEL (g_io_channel_get_type ())
+/**
+ * G_TYPE_IO_CONDITION:
+ * 
+ * The #GType for #GIOCondition.
+ */
 #define G_TYPE_IO_CONDITION (g_io_condition_get_type ())
 
 G_END_DECLS
